#!/bin/bash
# http://aqualung.factorial.hu/
#
# script : til <rob DOT til DOT freedman AT googlemail DOT com>
REPO=http://zenwalk.pinguix.com/user-accounts/tilderb
SVN_URL=https://aqualung.svn.sourceforge.net/svnroot/aqualung/trunk
set -e -u -x
#
# leave empty for latest revision
revision=
build=66.1
arch=i686
tune=i686
#tune=${tune:-pentium-m}

PKG_SRC="$REPO/extra/xap/aqualung/build-aqualung-svn.sh"

# checkout source
[ -z $revision ] || revision="-r $revision"
if [ -d aqualung-svn ]; then
	svn up $revision aqualung-svn
else
	svn co $revision $SVN_URL aqualung-svn
fi
version=r$(LC_ALL=C svn info aqualung-svn | grep '^Revision' | awk '{print $2}')

pkgname=aqualung-$version
package=$pkgname-$arch-$build

# where to build
CWD=$(pwd)
TMP=${TMP:-$CWD}
SRC=$TMP/$pkgname
PKG=$TMP/$package

# clean start
[ -d $PKG ] && rm -fr $PKG
[ -d $SRC ] && rm -fr $SRC
#
mkdir -p $PKG/{install,usr/{src,doc}/$pkgname}

# out-of-source-build doesn't work
cp -a aqualung-svn $SRC
cd $SRC
./autogen.sh

# 'Add URL' no prefix "http://"  
sed -i 's|(url_entry), "http://"|(url_entry), ""|' ./src/playlist.c

./configure --help >$CWD/configure.help
CFLAGS="-O2 -march=$arch -mtune=$tune" \
CPPFLAGS="-O2 -march=$arch -mtune=$tune" \
./configure \
    --prefix=/usr \
    --mandir=/usr/man \
    --with-ladspa=no \
    --with-mod=no \
    --with-ifp=no \
    --with-lavc=no \
    --with-jack=no \
    --with-lua=yes \
    --with-mac=yes \
    --with-mpc=yes \
    --with-ogg=yes \
    --with-oss=yes \
    --with-src=yes \
    --with-alsa=yes \
    --with-cdda=yes \
    --with-cddb=yes \
    --with-flac=yes \
    --with-lame=yes \
    --with-loop=yes \
    --with-mpeg=yes \
    --with-speex=yes \
    --with-systray=yes \
    --with-wavpack=yes \
    --with-sndfile=yes \
    --with-vorbisenc=yes || exit 1

# --docdir=/usr/doc/$pkgname  
 
make || exit 1
make install DESTDIR=$PKG

# docs; remove misplaced 
rm -fr $PKG/usr/share/aqualung/doc/
#
cp -a AUTHORS COPYING ChangeLog README  \
	$PKG/usr/doc/$pkgname
cd doc
make aqualung-doc
# helperline
(cd $PKG;find usr -printf "%M %u:%g %p %l\n" |sort >$CWD/make.installed)

# html in-one-page
tar xjf aqualung-doc-html.tar.bz2 --strip-components=1 -C $PKG/usr/doc/$pkgname

# fixup build 
cd $PKG
# man page
[ -d usr/man ] && find usr/man -type f -exec gzip -9 {} \;

# strip symbols
strip --strip-unneeded usr/bin/aqualung

# slack-desc
#       |-----handy-ruler------------------------------------------------------|
cat <<EOF > install/slack-desc
aqualung: Aqualung (an advanced music player)
aqualung:
aqualung: It plays audio CDs, internet radio streams and podcasts 
aqualung: as well as soundfiles in just about any audio format and 
aqualung: has the feature of inserting no gaps between adjacent tracks.
aqualung:
EOF
# desktop icons
for px in 16 24 32 48; do
	mkdir -p usr/share/icons/hicolor/${px}x${px}/apps
	mv usr/share/aqualung/icon_${px}.png \
			 usr/share/icons/hicolor/${px}x${px}/apps/aqualung.png
done
# aqualung.desktop  
# disabled by ffmpeg: audio/mp4;audio/aac;audio/ac3
mkdir -p usr/share/applications
cat << EOF > usr/share/applications/aqualung.desktop
[Desktop Entry]
Type=Application
Name=Aqualung
GenericName=Audio player
Comment=Gapless audio player with jack, alsa and oss support
Encoding=UTF-8
Icon=aqualung
Exec=aqualung
Terminal=false
MimeType=;audio/basic;audio/mpeg;audio/mpegurl;audio/vnd.rn-realaudio;audio/vorbis;audio/x-adpcm;audio/x-flac;audio/x-mp2;audio/x-mp3;audio/x-mpegurl;audio/x-ms-wma;audio/x-oggflac;audio/x-speex;audio/x-vorbis;audio/x-wav;
Categories=GTK;AudioVideo;Audio;Player;
StartupNotify=true
EOF

# the build script
cp $CWD/build-aqualung-svn.sh usr/src/$pkgname
#
rm -fr usr/share/locale/
# done
fakeroot /sbin/makepkg -l y -c n $CWD/$package.txz
cd $CWD
depfinder $PKG > $package.dep
echo "$PKG_SRC" > $package.src
md5sum $package.txz > $package.md5
